@@ -5,12 +5,20 @@
 # author:    Ingy döt Net <ingy@cpan.org>
 # license:   perl
 # copyright: 2011
+# see:
+# - Module::Package::Plugin
+# - Module::Install::Package
+# - Module::Package::Tutorial
 
 package Module::Package;
 use 5.005;
 use strict;
 
-$Module::Package::VERSION = '0.12';
+BEGIN {
+    $Module::Package::VERSION = '0.18';
+    $inc::Module::Package::VERSION ||= $Module::Package::VERSION;
+    @inc::Module::Package::ISA = __PACKAGE__;
+}
 
 sub import {
     eval "use inc::Module::Install 1.01 (); 1" or die $@;
